@@ -213,26 +213,28 @@ def propose_imputation_method(
         )
 
     # Handle dependency rule columns (specific calculations)
-    if metadata.dependency_rule and metadata.dependent_column:
+    dependency_rule = getattr(metadata, 'dependency_rule', None)
+    if dependency_rule and metadata.dependent_column:
         return ImputationProposal(
             method=ImputationMethod.BUSINESS_RULE,
-            rationale=f"Column has dependency rule on {metadata.dependent_column}: {metadata.dependency_rule}",
+            rationale=f"Column has dependency rule on {metadata.dependent_column}: {dependency_rule}",
             parameters={
                 "dependent_column": metadata.dependent_column,
-                "rule": metadata.dependency_rule,
+                "rule": dependency_rule,
                 "rule_type": "dependency",
             },
             confidence_score=get_confidence_score(),
         )
 
     # Handle business rule columns (general constraints)
-    if metadata.business_rule and metadata.dependent_column:
+    business_rule = getattr(metadata, 'business_rule', None)
+    if business_rule and metadata.dependent_column:
         return ImputationProposal(
             method=ImputationMethod.BUSINESS_RULE,
-            rationale=f"Column has business rule dependency on {metadata.dependent_column}: {metadata.business_rule}",
+            rationale=f"Column has business rule dependency on {metadata.dependent_column}: {business_rule}",
             parameters={
                 "dependent_column": metadata.dependent_column,
-                "rule": metadata.business_rule,
+                "rule": business_rule,
                 "rule_type": "business",
             },
             confidence_score=get_confidence_score(),
